import logging

from ._ldaps import LdapObject
from ._translators import get_windows_time_delta, TimeUnits
from ._domain import _get_domain_root_attribute


logger = logging.getLogger(__name__)


def get_min_password_age(connection: LdapObject) -> TimeUnits:
    return get_windows_time_delta(_get_domain_root_attribute(connection, attribute="minPwdAge"))


def get_max_password_age(connection: LdapObject) -> TimeUnits:
    return get_windows_time_delta(_get_domain_root_attribute(connection, attribute="maxPwdAge"))


def get_minimum_password_length(connection: LdapObject) -> int:
    return int(_get_domain_root_attribute(connection, attribute="minPwdLength"))


def get_password_history_length(connection: LdapObject) -> int:
    return int(_get_domain_root_attribute(connection, attribute="pwdHistoryLength"))


def get_lockout_threshold(connection: LdapObject) -> int:
    return int(_get_domain_root_attribute(connection, attribute="lockoutThreshold"))


def get_lockout_duration(connection: LdapObject) -> TimeUnits:
    return get_windows_time_delta(_get_domain_root_attribute(connection, attribute="lockoutDuration"))
